@@ -263,6 +263,8 @@ class ElasticEntity(BaseEntity):
         return [dict(item.to_dict(), **dict(_id=item._id)) for item in _items]
 
 class Page(ElasticEntity):
+    on_put = Signal()
+
     _schemas = {     
         'project': str, 
         'suggest': str, # search_as_you_type
@@ -381,6 +383,7 @@ class Page(ElasticEntity):
         'kyc_deposit': bool,
         'kyc_withdrawal': bool,
         'welcome_package': str,
+        'welcome_package_geo': list,
         'welcome_package_max_bonus': int,
         'welcome_package_match': int,
         'welcome_package_note': str,
@@ -954,16 +957,22 @@ class Guest(AnonymousUserMixin):
 
 
 class Actor(ElasticEntity, Guest):
+    on_put = Signal()
+
     _schemas = {
         'id': str,
         'project': str,
         'username': str,
+        'password': str,
         'last_auth': DateTimeField,
         'actor_is_active': bool,
         'actor_is_admin': bool,
         'ip': str,
         'ua': str,
         'cid': str,
+        'sign_date': DateTimeField,
+        'skype': str,
+        'comment': str,
     }
     
     @classmethod
